#!/bin/sh

THIS_DIR=`dirname $0`

TEMPLATES="$THIS_DIR/templates"
PERSON_SCRIPT="$THIS_DIR/../imip_person.py"
RESOURCE_SCRIPT="$THIS_DIR/../imip_resource.py"
SHOWMAIL="$THIS_DIR/../tools/showmail.py"
STORE=/tmp/store
STATIC=/tmp/static
PREFS=/tmp/prefs
ARGS="-S $STORE -P $STATIC -p $PREFS -d"
USER="mailto:resource-room-confroom@example.com"
SENDER="mailto:paul.boddie@example.com"
FBFILE="$STORE/$USER/freebusy"
FBSENDERFILE="$STORE/$SENDER/freebusy"
FBSENDEROTHERFILE="$STORE/$SENDER/freebusy-other/$USER"
TAB=`printf '\t'`

OUTGOING_SCRIPT="$THIS_DIR/../imip_person_outgoing.py"

ERROR=err.tmp

rm -rf $STORE
rm -rf $STATIC
rm -rf $PREFS
rm -f $ERROR
rm -f out*.tmp

mkdir -p "$PREFS/$USER"
echo 'Europe/Oslo' > "$PREFS/$USER/TZID"
echo 'share' > "$PREFS/$USER/freebusy_sharing"

mkdir -p "$PREFS/$SENDER"
echo 'Europe/Oslo' > "$PREFS/$SENDER/TZID"
echo 'always' > "$PREFS/$SENDER/event_refreshing"

# Publish an event, testing registration in the outgoing handler.

"$OUTGOING_SCRIPT" $ARGS < "$TEMPLATES/event-request-recurring.txt" 2>> $ERROR

   grep -q "^20141212T090000Z${TAB}20141212T100000Z" "$FBSENDERFILE" \
&& echo "Success" \
|| echo "Failed"

# Present the request to the recipient.

  "$RESOURCE_SCRIPT" $ARGS < "$TEMPLATES/event-request-recurring.txt" 2>> $ERROR \
| "$SHOWMAIL" \
> out1.tmp

   grep -q 'METHOD:REPLY' out1.tmp \
&& echo "Success" \
|| echo "Failed"

   grep -q "^20141212T090000Z${TAB}20141212T100000Z" "$FBFILE" \
&& echo "Success" \
|| echo "Failed"

# Present the response to the sender.

  "$PERSON_SCRIPT" $ARGS < out1.tmp 2>> $ERROR \
| "$SHOWMAIL" \
> out2.tmp

   grep -q "^20141212T090000Z${TAB}20141212T100000Z" "$FBSENDEROTHERFILE" \
&& echo "Success" \
|| echo "Failed"

# Attempt to add an occurrence to the event.

"$OUTGOING_SCRIPT" $ARGS < "$TEMPLATES/event-add-recurring.txt" 2>> $ERROR

   grep -q "^20141212T090000Z${TAB}20141212T100000Z" "$FBSENDERFILE" \
&& grep -q "^20150109T090000Z${TAB}20150109T100000Z" "$FBSENDERFILE" \
&& echo "Success" \
|| echo "Failed"

# Present the request to the recipient.

  "$RESOURCE_SCRIPT" $ARGS < "$TEMPLATES/event-add-recurring.txt" 2>> $ERROR \
| "$SHOWMAIL" \
> out3.tmp

   grep -q 'METHOD:REFRESH' out3.tmp \
&& echo "Success" \
|| echo "Failed"

   grep -q "^20141212T090000Z${TAB}20141212T100000Z" "$FBFILE" \
&& ! grep -q "^20150109T090000Z${TAB}20150109T100000Z" "$FBFILE" \
&& echo "Success" \
|| echo "Failed"

# Present the refresh message to the organiser.

  "$PERSON_SCRIPT" $ARGS < out3.tmp 2>> $ERROR \
| tee out4r.tmp \
| "$SHOWMAIL" \
> out4.tmp

   grep -q 'METHOD:REQUEST' out4.tmp \
&& echo "Success" \
|| echo "Failed"

# Present the request to the recipient.

  "$RESOURCE_SCRIPT" $ARGS < out4r.tmp 2>> $ERROR \
| tee out5r.tmp \
| "$SHOWMAIL" \
> out5.tmp

   grep -q 'METHOD:REPLY' out5.tmp \
&& echo "Success" \
|| echo "Failed"

   grep -q "^20141212T090000Z${TAB}20141212T100000Z" "$FBFILE" \
&& grep -q "^20150109T090000Z${TAB}20150109T100000Z" "$FBFILE" \
&& echo "Success" \
|| echo "Failed"

# Present the response to the sender.

  "$PERSON_SCRIPT" $ARGS < out5r.tmp 2>> $ERROR \
| "$SHOWMAIL" \
> out6.tmp

   grep -q "^20141212T090000Z${TAB}20141212T100000Z" "$FBSENDEROTHERFILE" \
&& grep -q "^20150109T090000Z${TAB}20150109T100000Z" "$FBSENDEROTHERFILE" \
&& echo "Success" \
|| echo "Failed"
