#!/bin/sh

DIRNAME=`dirname $0`

if [ -e "$DIRNAME/config.sh" ]; then
    . "$DIRNAME/config.sh"
else
    . /etc/imip-agent/config.sh
fi

if [ "$1" = "--no-locale-dir" ]; then
    NO_LOCALE_DIR=$1
else
    NO_LOCALE_DIR=
fi

# Agents and modules.

AGENTS="imip_person.py imip_person_outgoing.py imip_resource.py"
MODULES="markup.py imip_store.py vCalendar.py vContent.py vRecurrence.py"

if [ ! -e "$INSTALL_DIR" ]; then
    mkdir -p "$INSTALL_DIR"
fi

cp $AGENTS "$INSTALL_DIR"
cp $MODULES "$INSTALL_DIR"

if [ ! -e "$INSTALL_DIR/imiptools" ]; then
    mkdir "$INSTALL_DIR/imiptools"
fi
if [ ! -e "$INSTALL_DIR/imiptools/handlers" ]; then
    mkdir "$INSTALL_DIR/imiptools/handlers"
fi

# Remove any symbolic link to the config module.

if [ -h "$INSTALL_DIR/imiptools/config.py" ]; then
    rm "$INSTALL_DIR/imiptools/config.py"
fi

# Copy modules into the installation directory.

cp imiptools/*.py "$INSTALL_DIR/imiptools/"
cp imiptools/handlers/*.py "$INSTALL_DIR/imiptools/handlers/"

# Install the config module in a more appropriate location.

if [ ! -e "$CONFIG_DIR" ]; then
    mkdir -p "$CONFIG_DIR"
fi

if [ -e "$CONFIG_DIR/config.py" ]; then
    if [ ! -e "$CONFIG_DIR/config.py.backup" ]; then
        mv "$CONFIG_DIR/config.py" "$CONFIG_DIR/config.py.backup"
    fi
fi

if [ -e "$CONFIG_DIR/config.sh" ]; then
    if [ ! -e "$CONFIG_DIR/config.sh.backup" ]; then
        mv "$CONFIG_DIR/config.sh" "$CONFIG_DIR/config.sh.backup"
    fi
fi

# Replace the config module with a symbolic link.

mv "$INSTALL_DIR/imiptools/config.py" "$CONFIG_DIR/"
ln -s "$CONFIG_DIR/config.py" "$INSTALL_DIR/imiptools/config.py"

# Copy the config script.

cp tools/config.sh "$CONFIG_DIR/"

# Tools

TOOLS="fix.sh init.sh init_user.sh make_freebusy.py"

if [ ! -e "$INSTALL_DIR/tools" ]; then
    mkdir -p "$INSTALL_DIR/tools"
fi

for TOOL in $TOOLS; do
    cp "tools/$TOOL" "$INSTALL_DIR/tools/"
done

# Web manager interface.

if [ ! -e "$WEB_INSTALL_DIR" ]; then
    mkdir -p "$WEB_INSTALL_DIR"
fi

cp imip_manager.py "$WEB_INSTALL_DIR"
cp htdocs/styles.css "$WEB_INSTALL_DIR"

if [ ! -e "$WEB_INSTALL_DIR/imipweb" ]; then
    mkdir "$WEB_INSTALL_DIR/imipweb"
fi

cp imipweb/*.py "$WEB_INSTALL_DIR/imipweb/"

# Locale directory.

if [ ! "$NO_LOCALE_DIR" ] && [ -e "locale" ]; then
    for DIR in "locale/"*"/LC_MESSAGES" ; do
        mkdir -p "$INSTALL_DIR/$DIR"
        cp "$DIR/"*.mo "$INSTALL_DIR/$DIR/"
    done
fi
